%undefine _hardened_build
%define netcdfversion 4.9.2
%define netcdfnumversion %(echo %{netcdfversion} | tr -d .)

%{!?hdf5version: %define hdf5version 1.14.4}
%define hdf5numversion %( printf "%d%02d%02d" `echo %{hdf5version} | cut -d. -f1,2,3 --output-delimiter=" "`)

# compiler for which we are doing this
%{!?compiler: %define compiler gcc}
%{!?compilermajor: %define compilermajor 2024}
%{!?compilerminor: %define compilerminor 2}
%{!?openmpiversion: %define openmpiversion 4.1.6}
%{!?compilerversion:%define compilerversion %{compilermajor}.%{compilerminor}}
%define compilerversionnum %( echo %{compilerversion} | tr -d . )
%define openmpinumversion %( printf "%02d%02d%02d" `echo %{openmpiversion} | cut -d. -f1,2,3 --output-delimiter=" "` )
%define compilerrname %{compiler}%{compilerversionnum}

# modules defaults
%define modulefile_path_top /usr/local/share/Modules/modulefiles/cdo
# where modules really go
%define modulefile_path %{modulefile_path_top}/netcdf-%{netcdfversion}/hdf5-%{hdf5version}

%define localdir /usr/local/cdo/netcdf-%{netcdfversion}/hdf5-%{hdf5version}/%{version}

%define _prefix %{localdir}

# GCC Compiler
%if "%{compiler}" == "gcc"
# do nothing special for gcc for build prep
%define compilerbuildprep export F77=gfortran FC=gfortran
# no alias
%define modulefile_compiler_alias %{nil}
%define compilershort gcc
%define compilerlong gcc
%define compilerversionnum 446
%define compilerrname gcc
%global optflags -O2 -g -pipe -Wall -Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -grecord-gcc-switches -m64 -mtune=generic -fasynchronous-unwind-tables
%endif

%define compilerruntime BuildRequires: netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-devel netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-extra-devel \
Requires: netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion} netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-extra
%define compilerdevel Requires: netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-devel netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-devel netcdf%{netcdfnumversion}-%{compilerrname}-hdf5-%{hdf5numversion}-extra-devel

Version:        2.5.0
Name:           cdo%( echo %{version} | tr -d . )-netcdf%{netcdfnumversion}-hdf5%{hdf5numversion}
%define rname	cdo
Release:        1%{?dist}
Summary:        Climate Data Operators
License:        GPLv2
URL:            https://code.zmaw.de/projects/cdo
Source:         https://code.mpimet.mpg.de/attachments/download/26477/cdo-%{version}.tar.gz
BuildRequires:  libtool
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
#BuildRequires:  netcdf-cxx-devel
#Requires:       netcdf
%{compilerruntime}
BuildRequires:  environment-modules-local
Requires:       environment-modules-local
BuildRequires:	udunits2-devel libaec-devel eccodes-devel proj-devel libxml2-devel libuuid-devel libcurl-devel
BuildRequires:	python3-devel fftw-devel fftw-static
Requires:	udunits2 libaec eccodes proj libxml2 libuuid libcurl

%description
CDO is a collection of command line Operators to manipulate and analyse Climate model Data.
Supported data formats are GRIB, netCDF, SERVICE, EXTRA and IEG. There are more than 400
operators available. The following table provides a brief overview of the main categories.


Authors:
--------
    This program was developed at the Max-Planck-Institute for Meteorology.
    Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>, is the main author.
    Ralf Mueller, <ralf.mueller AT mpimet.mpg.de>
    Luis Kornblueh, <luis.kornblueh AT mpimet.mpg.de>
    Cedrick Ansorge, <cedrick.ansorge AT mpimet.mpg.de>
    Ralf Quast, <ralf.quast AT brockmann-consult.de>
    Send questions, comments and bug reports to <https://code.zmaw.de/projects/cdo>


%prep
%setup -n %{rname}-%{version}

%build
module load hdf5 netcdf
%configure --prefix=%{_prefix} --with-netcdf \
	--with-libxml2=yes \
	--with-szlib=yes \
	--with-hdf5=yes \
	--with-udunits2=/usr/include/udunits2/ \
	--with-util-linux-uuid \
	--with-eccodes=yes \
	--with-grib_api=yes \
	--with-proj=/usr \
	--with-curl=/usr \
	--with-fftw3
make 

%install
module load hdf5 netcdf
%make_install

mkdir -p ${RPM_BUILD_ROOT}/%{modulefile_path}
cat > ${RPM_BUILD_ROOT}/%{modulefile_path}/%{version} <<ENDFILE
#%Module

# NOTE: This is an automatically-generated file!  (generated by the
# cdo rpm).  Any changes made here will be lost a) if the RPM is
# uninstalled, or b) if the RPM is upgraded or uninstalled.

proc ModulesHelp { } {
   puts stderr "This module adds cdo %{version} compiled with netcdf-%{netcdfversion} and hdf5-%{hdf5version} to various paths"
}

module-whatis   "Sets up cdo %{version} compiled with netcdf-%{netcdfversion} and hdf5-%{hdf5version} in your environment"

prepend-path PATH "%{_bindir}"
conflict cdo
prereq hdf5 netcdf
ENDFILE

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,755)
%doc AUTHORS ChangeLog NEWS OPERATORS README doc/cdo.pdf doc/cdo_refcard.pdf
%{_prefix}/bin/cdo
%dir %{modulefile_path_top}
%dir %{modulefile_path_top}/*
%dir %{modulefile_path}
%{modulefile_path}/%{version}

%changelog
* Fri Apr 24 2020 - Daniele Branchini <dbranchini@arpae.it> - 1.9.8-1
- Upstream update (fixes #1)

* Fri Sep 14 2018 - Daniele Branchini <dbranchini@arpae.it> - 1.9.5-1
- First build
